/*
 * Example Code for the Paper
 *
 * "Mesh Saliency via Local Curvature Entropy", Eurographics 2016
 *
 * by M. Limper, A. Kuijper and D. Fellner
 *
 */

#include "meshIO.h"

#include <fstream>
#include <iomanip>

#include "utils.h"


namespace lce
{

//------------------------------------------------------------------------------------------------------------------

bool loadFile(TriMesh & mesh, const std::string & filename)
{
    // show OpenMesh errors only in debug version
#ifdef NDEBUG
    omerr().disable();
#endif

    // load custom "quality" property, if it exists
    OpenMesh::IO::Options readOptions = OpenMesh::IO::Options::Custom;

    if (!OpenMesh::IO::read_mesh(mesh, filename, readOptions))
    {
        std::cerr << "Could not read file \"" << filename << "\"!" << std::endl;
        return false;
    }

    mesh.triangulate();

    return true;
}

//------------------------------------------------------------------------------------------------------------------

bool saveFile(TriMesh & mesh, const std::string & filename)
{
    OpenMesh::IO::Options saveOptions = (OpenMesh::IO::Options::VertexColor |
                                         OpenMesh::IO::Options::Custom       );

    if (!OpenMesh::IO::write_mesh(mesh, filename, saveOptions))
    {
        std::cerr << "Could not write mesh file \"" << filename << "\"!" << std::endl;
        return false;
    }

    return true;
}

//------------------------------------------------------------------------------------------------------------------

} // namespace lce
